import * as ec2 from '@aws-cdk/aws-ec2';
import { Construct, Resource, ResourceProps, Stack, Duration } from '@aws-cdk/core';
import * as iam from '@aws-cdk/aws-iam';
export declare class VpcProvider extends Stack {
    static getOrCreate(scope: Construct): ec2.IVpc;
}
export declare enum BlockDuration {
    ONE_HOUR = 60,
    TWO_HOURS = 120,
    THREE_HOURS = 180,
    FOUR_HOURS = 240,
    FIVE_HOURS = 300,
    SIX_HOURS = 360
}
export declare enum InstanceInterruptionBehavior {
    HIBERNATE = "hibernate",
    STOP = "stop",
    TERMINATE = "terminate"
}
export interface SpotFleetLaunchTemplateConfig {
    readonly spotfleet: SpotFleet;
    readonly launchTemplate: ILaunchtemplate;
}
export interface ILaunchtemplate {
    bind(spotfleet: SpotFleet): SpotFleetLaunchTemplateConfig;
}
export declare class LaunchTemplate implements ILaunchtemplate {
    bind(spotfleet: SpotFleet): SpotFleetLaunchTemplateConfig;
}
export interface BaseSpotFleetProps extends ResourceProps {
    readonly defaultInstanceType?: ec2.InstanceType;
    readonly blockDuration?: BlockDuration;
    readonly instanceInterruptionBehavior?: InstanceInterruptionBehavior;
    readonly instanceRole?: iam.Role;
    readonly targetCapacity?: number;
    readonly mapRole?: boolean;
    readonly bootstrapEnabled?: boolean;
    readonly validFrom?: string;
    readonly validUntil?: string;
    readonly terminateInstancesWithExpiration?: boolean;
    readonly customAmiId?: string;
    readonly vpcSubnet?: ec2.SubnetSelection;
}
export interface SpotFleetProps extends BaseSpotFleetProps {
    readonly launchTemplate?: ILaunchtemplate;
    readonly eipAllocationId?: string;
}
export declare class SpotFleet extends Resource {
    readonly instanceRole: iam.IRole;
    readonly defaultInstanceType: ec2.InstanceType;
    readonly targetCapacity?: number;
    readonly spotFleetId: string;
    readonly launchTemplate: ILaunchtemplate;
    validUntil?: string;
    constructor(scope: Construct, id: string, props: SpotFleetProps);
    expireAfter(duration: Duration): void;
}
